@@ -4,9 +4,9 @@ use strict;
 use warnings;
 use parent qw( Alien::Base );
 
-our $VERSION = '1.003';
-
+our $VERSION = '1.005';
 
+#  make sure we find geos and geos_c
 sub dynamic_libs {
     my ($class) = @_;
 
@@ -23,26 +23,36 @@ sub dynamic_libs {
         return wantarray ? @libs : $libs[0];
     }
     else {
-        #  should just send shared to SUPER::dynamic_libs
-        #  as the code is the same
-
         my $dir = $class->dist_dir;
+
         my $dynamic = Path::Tiny->new($class->dist_dir, 'dynamic');
-      
-        if(-d $dynamic) {
-            return FFI::CheckLib::find_lib(
-                lib        => '*',
-                libpath    => "$dynamic",
-                systempath => [],
-            );
+        if (-d $dynamic) {
+            $dir = $dynamic;
         }
         
-        return FFI::CheckLib::find_lib(
-            lib        => '*',
-            libpath    => $dir,
-            systempath => [],
-            recursive  => 1,
-        );
+        my @libs;
+        if ($^O =~ /mswin/i) {
+            #warn "Checking $dir\n";
+            #  until FFI::CheckLib::find_lib handles names like geos-3-7-0.dll 
+            my $dh;
+            opendir $dh, "$dir/bin" or die "Unable to open dir handle for $dir/bin";
+            my @dlls
+              = map {"$dir/$_"}
+                grep {/geos.+\.dll$/}
+                readdir $dh;
+            push @libs, @dlls;
+            $dh->close;
+        }
+        else {
+            push @libs, FFI::CheckLib::find_lib(
+                lib        => ['geos', 'geos_c'],
+                libpath    => $dir,
+                systempath => [],
+                recursive  => 1,
+            );
+        }
+        #warn "FOUND LIBS: " . join (':', @libs);
+        return wantarray ? @libs : $libs[0];
     }
 }
 
